#
# spec file for package libesmtp
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define so_ver 6.2.0
%define lname libesmtp6_2_0
Name:           libesmtp
Version:        1.1.0
Release:        3.2
Summary:        A Library for Posting Electronic Mail
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            https://libesmtp.github.io/
Source0:        https://github.com/libesmtp/libESMTP/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         add_ntlm.patch
#PATCH-FIX-UPSTREAM libesmtp-c99.patch boo#1225800 mjambor@suse.cz
Patch1:         libesmtp-c99.patch
BuildRequires:  libtool
BuildRequires:  meson >= 0.50.0
BuildRequires:  openssl-devel >= 1.1.0
BuildRequires:  pkgconfig

%description
libESMTP is a library to manage posting (or submission of) electronic
mail using SMTP to a preconfigured Mail Transport Agent (MTA). It may
be used as part of a Mail User Agent (MUA) or another program that
must be able to post electronic mail but where mail functionality is
not that program's primary purpose.

%package -n %{lname}
Summary:        A Library for Posting Electronic Mail
Group:          System/Libraries

%description -n %{lname}
libESMTP is a library to manage posting (or submission of) electronic
mail using SMTP to a preconfigured Mail Transport Agent (MTA). It may
be used as part of a Mail User Agent (MUA) or another program that
must be able to post electronic mail but where mail functionality is
not that program's primary purpose.

%package devel
Summary:        A Library for Posting Electronic Mail
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}

%description devel
libESMTP is a library to manage posting (or submission of) electronic
mail using SMTP to a preconfigured Mail Transport Agent (MTA).

This subpackage contains the API definition files.

%prep
%autosetup -p1 -n libESMTP-%{version}

%build
%meson \
  -Dntlm=disabled
%meson_build

%install
%meson_install

%post   -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%files -n %{lname}
%license LICENSE
%doc README.md docs/*
%{_libdir}/esmtp-plugins-%{so_ver}
%{_libdir}/libesmtp.so.%{so_ver}

%files devel
%{_includedir}/*.h
%{_libdir}/libesmtp.so
%{_libdir}/pkgconfig/libesmtp-1.0.pc

%changelog
* Mon Dec 16 2024 David Disseldorp <ddiss@suse.com>
- Disable support for insecure NTLM authentication; jsc#PED-11790
* Wed Jul 10 2024 Martin Jambor <mjambor@suse.com>
- Added libesmtp-c99.patch which adds a required feature macro
  definition so that strlcpy function is properly declared in the
  standard header file.  [boo#1225800]
* Tue Dec 27 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.1.0:
  * CVE-2019-19977: avoid potential stack overflow in NTLM authenticator.
  * Migrate build system to Meson
  * Remove GNU libltdl support, assume dlopen() always available.
  * Use a linker map to restrict public symbols to API only.
  * Add sentinel and ‘format printf’ attributes to function declarations.
  * Remove getaddrinfo() implementation.
  * Use strlcpy() for safer string copies, provide implementation
    for systems that need it.
  * Update ‘application data’ APIs
  * Add ‘smtp_get_server_name()’ API.
  * Collect replacement functions into missing.c
  * Prohibit Resent-Reply-To: header.
  * Use canonic domain name of MTA where known
  * Implement rfc2822date() with strftime() if available.
  * add option for XDG file layout convention instead of ~/.authenticate
  * OpenSSL
    + Remove support for OpenSSL versions before v1.1.0
    + Update OpenSSL API calls used for modern versions
    + Require TLS v1 or higher
  * Add add_ntlm.patch
  * Drop the following patches:
    + libesmtp-removedecls.diff
    + libesmtp-1.0.4-bloat.patch
    + libesmtp-fix-cve-2019-19977.patch
    + libesmtp-openssl11.patch
    + libesmtp-tlsv12.patch
* Fri Aug  6 2021 Yifan Jiang <yfjiang@suse.com>
- Add libesmtp-fix-cve-2019-19977.patch: Fix stack-based buffer
  over-read in ntlm/ntlmstruct.c (bsc#1160462 bsc#1189097).
* Mon Jan 14 2019 kukuk@suse.de
- Use %%license instead of %%doc [bsc#1082318]
* Sat Mar  3 2018 jengelh@inai.de
- Drop ineffective --with-pic. Drop %%__-type macro indirections.
  Drop redundant %%clean section.
- Implement shared library packaging guideline.
* Fri Feb 16 2018 crrodriguez@opensuse.org
- SSL support was silently lost on openSSL 1.1 update.
  libesmtp-openssl11.patch makes things work again.
* Fri Sep 30 2016 crrodriguez@opensuse.org
- Add libesmtp-tlsv12.patch: All TLS clients must support and use
  the highest TLS version available if possible not only TLS 1.0.
  Patch sent to upstream long time ago, no response. website
  has also vanished from the internet (bsc#1005909).
- Pass --disable-isoc to configure, pick the compiler's default C
  standard mode (currently gnu11).
* Mon Feb  4 2013 coolo@suse.com
- update license to new format
* Tue Aug 10 2010 dimstar@opensuse.org
- Update to version 1.0.6:
  + Each component matched by match-domain() is either a single
    '*' which matches anything or a case-insensitive comparison
    with a string of alphanumeric characters or a '-'.
- Changes from version 1.0.5:
  + The Gmail server reports enhanced status codes but then fails
    to provide them in some cases. The parser is now tolerant of
    this but warns the application using a new event flag
    SMTP_EV_SYNTAXWARNING that it is progressing despite the syntax
    error.
  + Fixed bug where To, Cc, Bcc etc. accepted only single values
    instead of a list.
  + Fix reversed comparison on the return value of gettimeofday().
- Drop upstream fixed patches libesmtp-1.0.4-multiple-cc.patch and
  libestmp-commonname.diff.
- Cleaned spec file using spec-cleaner.
* Wed Apr 28 2010 freitag@novell.com
- Add libestmp-commonname.diff to do stricter check on commonName
  bnc#585393.
* Wed Aug  6 2008 bwalle@suse.de
- allow multiple calls of smtp_set_header() for Cc and Bcc headers
- disable lwres because we don't want to have a daemon (the lwresd)
  running just for address resolution
* Tue Sep  4 2007 mrueckert@suse.de
- remove postfix from the buildrequires
- do not package generic INSTALL file
* Tue Sep  4 2007 crrodriguez@suse.de
- fix #307257 missing requires of the libesmtp-devel package
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 17 2006 lmichnovic@suse.cz
- Updated to version 1.0.4
- enabled support for lwres: lwres_includedir.patch; bind-devel added into NFB
- enabled support for ntlm, etrn
* Wed Nov  2 2005 dmueller@suse.de
- don't build as root
* Mon Sep 26 2005 mls@suse.de
- move .so symlink into devel package
- make devel package require base package
* Sun May  8 2005 mmj@suse.de
- Don't declare things we have for sure on linux
* Fri Mar 26 2004 mmj@suse.de
- Add postfix to # neededforbuild
* Thu Feb 19 2004 sbrabec@suse.cz
- Updated to version 1.0.2.
* Wed Jul 30 2003 hhetter@suse.de
- initial SuSE package
